@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainConfigsysWidgetContainer.php 3570 2010-09-07 10:39:53Z fishbone $
+ * @version    SVN: $Id: admin_mainConfigsysWidgetContainer.php 3678 2010-10-07 08:49:40Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainConfigsystemBaseWidgetContainer.php');
@@ -20,6 +20,7 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 {
 	private $db;	// DB接続オブジェクト
 	private $adminTheme;		// 管理画面用jQueryUIテーマ
+	private $systemTemplate;// システム画面用テンプレート
 	const CF_USE_SSL = 'use_ssl';		// SSL機能を使用するかどうか
 	const CF_USE_SSL_ADMIN = 'use_ssl_admin';		// 管理画面にSSL機能を使用するかどうか
 	const CAN_DETAIL_CONFIG	= 'permit_detail_config';				// 詳細設定が可能かどうか
@@ -43,11 +44,13 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 	const CF_SSL_URL = 'ssl_root_url';				// SSL用のルートURL
 	const CF_CONNECT_SERVER_URL = 'default_connect_server_url';			// ポータル接続先URL
 	const CF_CONFIG_WINDOW_OPEN_TYPE = 'config_window_open_type';		// ウィジェット設定画面のウィンドウ表示タイプ(0=別ウィンドウ、1=タブ)
+	const CF_SYSTEM_TEMPLATE = 'msg_template';			// メッセージ用テンプレート取得キー
 	const CF_ADMIN_DEFAULT_THEME = 'admin_default_theme';		// 管理画面用jQueryUIテーマ
 	const INSTALL_DT = 'install_dt';		// システムインストール日時
 	const WORK_DIR = 'work_dir';			// 作業ディレクトリ
 	const WRITE_TEST_FILENAME = '_magic3_test';			// 書き込みテスト用ファイル名
 	const DEFAULT_THEME_DIR = '/ui/themes';				// jQueryUIテーマ格納ディレクトリ
+	const DEFAULT_SYSTEM_TEMPLATE_ID = '_system';				// デフォルトのシステム画面用テンプレート
 	
 	/**
 	 * コンストラクタ
@@ -107,6 +110,7 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 			
 		$lang = $request->trimValueOf('item_lang');
 		$workDir = $request->trimValueOf('item_work_dir');
+		$this->systemTemplate = $request->trimValueOf('item_systemplate');	// システム画面用テンプレート
 		$this->adminTheme = $request->trimValueOf('item_theme');		// 管理画面用jQueryUIテーマ
 		if ($act == 'update'){		// 設定更新のとき
 			$isErr = false;
@@ -161,6 +165,9 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 				$workDir = rtrim($workDir, '/');// 最後の「/」を除く
 				if (!$this->db->updateSystemConfig(self::WORK_DIR, $workDir)) $isErr = true;
 			}
+			if (!$isErr){
+				if (!$this->db->updateSystemConfig(self::CF_SYSTEM_TEMPLATE, $this->systemTemplate)) $isErr = true;// システム画面用テンプレート
+			}			
 			if (!$isErr){
 				if (!$this->db->updateSystemConfig(self::CF_ADMIN_DEFAULT_THEME, $this->adminTheme)) $isErr = true;// 管理画面用jQueryUIテーマ
 			}
@@ -192,6 +199,7 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 			$siteMobileInPublic = $this->gSystem->siteMobileInPublic(true/*再取得*/);	// 携帯用サイトの公開状況
 			$siteSmartphoneInPublic = $this->gSystem->siteSmartphoneInPublic(true/*再取得*/);	// スマートフォン用サイトの公開状況
 			$configWindowOpenByTab = $this->db->getSystemConfig(self::CF_CONFIG_WINDOW_OPEN_TYPE);			// ウィジェット設定画面をタブで開くかどうか
+			$this->systemTemplate		= $this->db->getSystemConfig(self::CF_SYSTEM_TEMPLATE);// システム画面用テンプレート
 			$this->adminTheme = $this->db->getSystemConfig(self::CF_ADMIN_DEFAULT_THEME);		// 管理画面用jQueryUIテーマ
 			
 			// メニュー項目の制御
@@ -241,11 +249,15 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 			$siteMobileInPublic = $this->gSystem->siteMobileInPublic(true/*再取得*/);	// 携帯用サイトの公開状況
 			$siteSmartphoneInPublic = $this->gSystem->siteSmartphoneInPublic(true/*再取得*/);	// スマートフォン用サイトの公開状況
 			$configWindowOpenByTab = $this->db->getSystemConfig(self::CF_CONFIG_WINDOW_OPEN_TYPE);			// ウィジェット設定画面をタブで開くかどうか
+			$this->systemTemplate		= $this->db->getSystemConfig(self::CF_SYSTEM_TEMPLATE);// システム画面用テンプレート
 			$this->adminTheme = $this->db->getSystemConfig(self::CF_ADMIN_DEFAULT_THEME);		// 管理画面用jQueryUIテーマ
 		}
 		// 言語選択メニューを作成
 		$this->db->getAllLang(array($this, 'langLoop'));
 		
+		// システム画面用テンプレート作成
+		$this->db->getAllTemplateList(0/*PC用*/, array($this, 'sysTemplateLoop'), false/*利用不可も表示*/);
+		
 		// jQueryUIテーマ選択メニュー作成
 		$this->createThemeMenu($this->gEnv->getSystemRootPath() . self::DEFAULT_THEME_DIR);
 		
@@ -604,5 +616,31 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 			$dir->close();
 		}
 	}
+	/**
+	 * システム画面用テンプレート一覧を作成
+	 *
+	 * @param int $index			行番号(0～)
+	 * @param array $fetchedRow		フェッチ取得した行
+	 * @param object $param			未使用
+	 * @return bool					true=処理続行の場合、false=処理終了の場合
+	 */
+	function sysTemplateLoop($index, $fetchedRow, $param)
+	{
+		$selected = '';
+		if ($fetchedRow['tm_id'] == $this->systemTemplate){
+			$selected = 'selected';
+		}
+		$name = $fetchedRow['tm_name'];
+		if ($fetchedRow['tm_id'] == self::DEFAULT_SYSTEM_TEMPLATE_ID) $name = '[デフォルト]';
+		
+		$row = array(
+			'value'    => $this->convertToDispString($fetchedRow['tm_id']),			// テンプレートID
+			'name'     => $this->convertToDispString($name),			// テンプレート名名
+			'selected' => $selected														// 選択中かどうか
+		);
+		$this->tmpl->addVars('systemplate_list', $row);
+		$this->tmpl->parseTemplate('systemplate_list', 'a');
+		return true;
+	}
 }
 ?>
