@@ -11,7 +11,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: index.php 3844 2010-11-19 08:29:00Z fishbone $
+ * @version    SVN: $Id: index.php 3862 2010-11-24 08:25:29Z fishbone $
  * @link       http://www.magic3.org
  */
 // 直接アクセスの防止
@@ -479,10 +479,12 @@ $HELP['adjustwidget']['title'] = 'ウィジェットタイトル、位置調整'
 $HELP['adjustwidget']['body'] = 'ウィジェットのタイトルやウィジェットの表示内容の位置調整を行います。';
 $HELP['adjustwidget_title']['title'] = 'タイトル名';
 $HELP['adjustwidget_title']['body'] = 'ウィジェットの上部に表示されるタイトル名を設定します。空に設定した場合はデフォルトのタイトル名が表示されます。「表示」チェックボックスでタイトルの表示、非表示の制御を行います。ここでの設定は他のすべての設定に優先します。';
-$HELP['adjustwidget_align']['title'] = '表示位置';
-$HELP['adjustwidget_align']['body'] = 'ウィジェットの表示内容の位置を設定します。';
+$HELP['adjustwidget_align']['title'] = 'テキスト表示位置';
+$HELP['adjustwidget_align']['body'] = 'ウィジェットの表示内容のテキストの位置を設定します。';
 $HELP['adjustwidget_margin']['title'] = 'マージン';
 $HELP['adjustwidget_margin']['body'] = 'ウィジェットの表示内容のマージンを設定します。空に設定したフィールドは指定なしになります。';
+$HELP['adjustwidget_render']['title'] = '描画処理';
+$HELP['adjustwidget_render']['body'] = '「Joomla!スタイルの描画処理」をオンにするとウィジェットの周囲の枠やタイトルが付加されます。チェックをはずした場合はウィジェットのプレーンな出力が表示されます。';
 
 // ########## リソースブラウズ ##########
 $HELP['resbrowse']['title'] = 'リソースブラウズ';
